==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewayRewriteRuleActionSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleActionSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Set of actions in the Rewrite Rule in Application Gateway.
 * @property requestHeaderConfigurations Request Header Actions in the Action Set.
 * @property responseHeaderConfigurations Response Header Actions in the Action Set.
 * @property urlConfiguration Url Configuration Action in the Action Set.
 */
public data class ApplicationGatewayRewriteRuleActionSetArgs(
    public val requestHeaderConfigurations: Output<List<ApplicationGatewayHeaderConfigurationArgs>>? =
        null,
    public val responseHeaderConfigurations: Output<List<ApplicationGatewayHeaderConfigurationArgs>>? =
        null,
    public val urlConfiguration: Output<ApplicationGatewayUrlConfigurationArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleActionSetArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleActionSetArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleActionSetArgs.builder()
            .requestHeaderConfigurations(
                requestHeaderConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .responseHeaderConfigurations(
                responseHeaderConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .urlConfiguration(
                urlConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationGatewayRewriteRuleActionSetArgs].
 */
@PulumiTagMarker
public class ApplicationGatewayRewriteRuleActionSetArgsBuilder internal constructor() {
    private var requestHeaderConfigurations: Output<List<ApplicationGatewayHeaderConfigurationArgs>>? =
        null

    private var responseHeaderConfigurations: Output<List<ApplicationGatewayHeaderConfigurationArgs>>? =
        null

    private var urlConfiguration: Output<ApplicationGatewayUrlConfigurationArgs>? = null

    /**
     * @param value Request Header Actions in the Action Set.
     */
    @JvmName("gbbfcphedlhstdlp")
    public suspend
    fun requestHeaderConfigurations(`value`: Output<List<ApplicationGatewayHeaderConfigurationArgs>>) {
        this.requestHeaderConfigurations = value
    }

    @JvmName("fwhgqdwdssrsydvq")
    public suspend fun requestHeaderConfigurations(
        vararg
        values: Output<ApplicationGatewayHeaderConfigurationArgs>,
    ) {
        this.requestHeaderConfigurations = Output.all(values.asList())
    }

    /**
     * @param values Request Header Actions in the Action Set.
     */
    @JvmName("mhwwssmsphddwdwi")
    public suspend
    fun requestHeaderConfigurations(values: List<Output<ApplicationGatewayHeaderConfigurationArgs>>) {
        this.requestHeaderConfigurations = Output.all(values)
    }

    /**
     * @param value Response Header Actions in the Action Set.
     */
    @JvmName("umnubmmeqnsfqtuh")
    public suspend
    fun responseHeaderConfigurations(`value`: Output<List<ApplicationGatewayHeaderConfigurationArgs>>) {
        this.responseHeaderConfigurations = value
    }

    @JvmName("adycytmiadsvknjk")
    public suspend fun responseHeaderConfigurations(
        vararg
        values: Output<ApplicationGatewayHeaderConfigurationArgs>,
    ) {
        this.responseHeaderConfigurations = Output.all(values.asList())
    }

    /**
     * @param values Response Header Actions in the Action Set.
     */
    @JvmName("rgpebuuolmqojoqf")
    public suspend
    fun responseHeaderConfigurations(values: List<Output<ApplicationGatewayHeaderConfigurationArgs>>) {
        this.responseHeaderConfigurations = Output.all(values)
    }

    /**
     * @param value Url Configuration Action in the Action Set.
     */
    @JvmName("tqtspoescrormmkx")
    public suspend fun urlConfiguration(`value`: Output<ApplicationGatewayUrlConfigurationArgs>) {
        this.urlConfiguration = value
    }

    /**
     * @param value Request Header Actions in the Action Set.
     */
    @JvmName("iqpbethnyuualppe")
    public suspend
    fun requestHeaderConfigurations(`value`: List<ApplicationGatewayHeaderConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param argument Request Header Actions in the Action Set.
     */
    @JvmName("jrnlbwnekudyumkd")
    public suspend
    fun requestHeaderConfigurations(argument: List<suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param argument Request Header Actions in the Action Set.
     */
    @JvmName("vqyocdxmsvghxnuk")
    public suspend fun requestHeaderConfigurations(
        vararg
        argument: suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param argument Request Header Actions in the Action Set.
     */
    @JvmName("kvyiqvtjcfjmxgsg")
    public suspend
    fun requestHeaderConfigurations(argument: suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param values Request Header Actions in the Action Set.
     */
    @JvmName("nyttsedphbkcatux")
    public suspend fun requestHeaderConfigurations(
        vararg
        values: ApplicationGatewayHeaderConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param value Response Header Actions in the Action Set.
     */
    @JvmName("rrdduswjxhnygttk")
    public suspend
    fun responseHeaderConfigurations(`value`: List<ApplicationGatewayHeaderConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param argument Response Header Actions in the Action Set.
     */
    @JvmName("ommidiklxobhksnw")
    public suspend
    fun responseHeaderConfigurations(argument: List<suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param argument Response Header Actions in the Action Set.
     */
    @JvmName("yxcfpanawdlkffyu")
    public suspend fun responseHeaderConfigurations(
        vararg
        argument: suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param argument Response Header Actions in the Action Set.
     */
    @JvmName("ylkegcuowdnywhyv")
    public suspend
    fun responseHeaderConfigurations(argument: suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param values Response Header Actions in the Action Set.
     */
    @JvmName("hgokcnipevkqnrco")
    public suspend fun responseHeaderConfigurations(
        vararg
        values: ApplicationGatewayHeaderConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param value Url Configuration Action in the Action Set.
     */
    @JvmName("ioaytyecqostrvsp")
    public suspend fun urlConfiguration(`value`: ApplicationGatewayUrlConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.urlConfiguration = mapped
    }

    /**
     * @param argument Url Configuration Action in the Action Set.
     */
    @JvmName("jhnisvqrffuigmcg")
    public suspend
    fun urlConfiguration(argument: suspend ApplicationGatewayUrlConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = ApplicationGatewayUrlConfigurationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.urlConfiguration = mapped
    }

    internal fun build(): ApplicationGatewayRewriteRuleActionSetArgs =
        ApplicationGatewayRewriteRuleActionSetArgs(
            requestHeaderConfigurations = requestHeaderConfigurations,
            responseHeaderConfigurations = responseHeaderConfigurations,
            urlConfiguration = urlConfiguration,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewayRewriteRuleActionSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleActionSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Set of actions in the Rewrite Rule in Application Gateway.
 * @property requestHeaderConfigurations Request Header Actions in the Action Set.
 * @property responseHeaderConfigurations Response Header Actions in the Action Set.
 * @property urlConfiguration Url Configuration Action in the Action Set.
 */
public data class ApplicationGatewayRewriteRuleActionSetArgs(
    public val requestHeaderConfigurations: Output<List<ApplicationGatewayHeaderConfigurationArgs>>? =
        null,
    public val responseHeaderConfigurations: Output<List<ApplicationGatewayHeaderConfigurationArgs>>? =
        null,
    public val urlConfiguration: Output<ApplicationGatewayUrlConfigurationArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleActionSetArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleActionSetArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewayRewriteRuleActionSetArgs.builder()
            .requestHeaderConfigurations(
                requestHeaderConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .responseHeaderConfigurations(
                responseHeaderConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .urlConfiguration(
                urlConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationGatewayRewriteRuleActionSetArgs].
 */
@PulumiTagMarker
public class ApplicationGatewayRewriteRuleActionSetArgsBuilder internal constructor() {
    private var requestHeaderConfigurations: Output<List<ApplicationGatewayHeaderConfigurationArgs>>? =
        null

    private var responseHeaderConfigurations: Output<List<ApplicationGatewayHeaderConfigurationArgs>>? =
        null

    private var urlConfiguration: Output<ApplicationGatewayUrlConfigurationArgs>? = null

    /**
     * @param value Request Header Actions in the Action Set.
     */
    @JvmName("burhdedjyqfpxxum")
    public suspend
    fun requestHeaderConfigurations(`value`: Output<List<ApplicationGatewayHeaderConfigurationArgs>>) {
        this.requestHeaderConfigurations = value
    }

    @JvmName("mxxloilehuhcxxmm")
    public suspend fun requestHeaderConfigurations(
        vararg
        values: Output<ApplicationGatewayHeaderConfigurationArgs>,
    ) {
        this.requestHeaderConfigurations = Output.all(values.asList())
    }

    /**
     * @param values Request Header Actions in the Action Set.
     */
    @JvmName("qtwxkiyjnwggjuwv")
    public suspend
    fun requestHeaderConfigurations(values: List<Output<ApplicationGatewayHeaderConfigurationArgs>>) {
        this.requestHeaderConfigurations = Output.all(values)
    }

    /**
     * @param value Response Header Actions in the Action Set.
     */
    @JvmName("lewdkedkcidepswk")
    public suspend
    fun responseHeaderConfigurations(`value`: Output<List<ApplicationGatewayHeaderConfigurationArgs>>) {
        this.responseHeaderConfigurations = value
    }

    @JvmName("mrciumsihfburmjc")
    public suspend fun responseHeaderConfigurations(
        vararg
        values: Output<ApplicationGatewayHeaderConfigurationArgs>,
    ) {
        this.responseHeaderConfigurations = Output.all(values.asList())
    }

    /**
     * @param values Response Header Actions in the Action Set.
     */
    @JvmName("ngtqclfkjcsdvbie")
    public suspend
    fun responseHeaderConfigurations(values: List<Output<ApplicationGatewayHeaderConfigurationArgs>>) {
        this.responseHeaderConfigurations = Output.all(values)
    }

    /**
     * @param value Url Configuration Action in the Action Set.
     */
    @JvmName("ytifmalnuodqpyne")
    public suspend fun urlConfiguration(`value`: Output<ApplicationGatewayUrlConfigurationArgs>) {
        this.urlConfiguration = value
    }

    /**
     * @param value Request Header Actions in the Action Set.
     */
    @JvmName("cwecdfywktqxvipj")
    public suspend
    fun requestHeaderConfigurations(`value`: List<ApplicationGatewayHeaderConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param argument Request Header Actions in the Action Set.
     */
    @JvmName("oxccflbtakbjysym")
    public suspend
    fun requestHeaderConfigurations(argument: List<suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param argument Request Header Actions in the Action Set.
     */
    @JvmName("bvocwlucrxdkcjhc")
    public suspend fun requestHeaderConfigurations(
        vararg
        argument: suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param argument Request Header Actions in the Action Set.
     */
    @JvmName("hhnycruuygqfqykq")
    public suspend
    fun requestHeaderConfigurations(argument: suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param values Request Header Actions in the Action Set.
     */
    @JvmName("maakxynvsllqfinl")
    public suspend fun requestHeaderConfigurations(
        vararg
        values: ApplicationGatewayHeaderConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requestHeaderConfigurations = mapped
    }

    /**
     * @param value Response Header Actions in the Action Set.
     */
    @JvmName("emaimnrcgnvwarup")
    public suspend
    fun responseHeaderConfigurations(`value`: List<ApplicationGatewayHeaderConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param argument Response Header Actions in the Action Set.
     */
    @JvmName("wktxlmlqadqbvvjk")
    public suspend
    fun responseHeaderConfigurations(argument: List<suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param argument Response Header Actions in the Action Set.
     */
    @JvmName("jjcscjxtdjlhidrf")
    public suspend fun responseHeaderConfigurations(
        vararg
        argument: suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param argument Response Header Actions in the Action Set.
     */
    @JvmName("jtkgsrwwiqwaqnre")
    public suspend
    fun responseHeaderConfigurations(argument: suspend ApplicationGatewayHeaderConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ApplicationGatewayHeaderConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param values Response Header Actions in the Action Set.
     */
    @JvmName("pgigcyonapksvhdj")
    public suspend fun responseHeaderConfigurations(
        vararg
        values: ApplicationGatewayHeaderConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.responseHeaderConfigurations = mapped
    }

    /**
     * @param value Url Configuration Action in the Action Set.
     */
    @JvmName("cwttgkspecpmowxs")
    public suspend fun urlConfiguration(`value`: ApplicationGatewayUrlConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.urlConfiguration = mapped
    }

    /**
     * @param argument Url Configuration Action in the Action Set.
     */
    @JvmName("lrqyftwpjnvnoigd")
    public suspend
    fun urlConfiguration(argument: suspend ApplicationGatewayUrlConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = ApplicationGatewayUrlConfigurationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.urlConfiguration = mapped
    }

    internal fun build(): ApplicationGatewayRewriteRuleActionSetArgs =
        ApplicationGatewayRewriteRuleActionSetArgs(
            requestHeaderConfigurations = requestHeaderConfigurations,
            responseHeaderConfigurations = responseHeaderConfigurations,
            urlConfiguration = urlConfiguration,
        )
}
